darkhistory.history.reionization.alphaA_recomb — DarkHistory documentation

# darkhistory.history.reionization.alphaA_recomb

`darkhistory.history.reionization.` `alphaA_recomb`(species, T)

  Case-A recombination coefficient.

  Parameters: | species : {‘HII’, ‘HeIIr’, ‘HeIId’, ‘HeIII’} Species of interest. T : float Matter temperature in eV.
  Returns: | float Case-A recombination coefficient in cm^3/s. See astro-ph/0607331.

#### Previous topic

darkhistory.history.reionization

#### Next topic

darkhistory.history.reionization.brem_cooling_rate

### This Page

Show Source